@@ -21,7 +21,7 @@ CAUTION: functions should PUSH results, not RETURN
 from pybtex.bibtex.exceptions import BibTeXError
 from pybtex.bibtex.utils import split_name_list
 from pybtex.core import Person
-from pybtex.bibtex.utils import bibtex_len
+from pybtex.bibtex.utils import bibtex_len, bibtex_prefix, bibtex_purify, bibtex_substring
 from pybtex.bibtex.names import format as format_bibtex_name
 
 class Builtin(object):
@@ -203,7 +203,7 @@ def missing(i):
 def newline(i):
     # FIXME bibtex does some automatic line breaking
     # needs more investigation
-    i.output('\n')
+    i.newline()
 
 @builtin('num.names$')
 def num_names(i):
@@ -220,13 +220,8 @@ def preamble(i):
 
 @builtin('purify$')
 def purify(i):
-    #FIXME need to strip TeX control sequences starting with backslash
     s = i.pop()
-    l = []
-    for char in s:
-        if char.isalpha() or char.isdigit() or char.isspace():
-            l.append(char)
-    i.push(''.join(l))
+    i.push(bibtex_purify(s))
 
 @builtin('quote$')
 def quote(i):
@@ -238,15 +233,10 @@ def skip(i):
 
 @builtin('substring$')
 def substring(i):
-    len = i.pop()
+    length = i.pop()
     start = i.pop()
-    s = i.pop()
-    if start > 0:
-        i.push(s[start - 1:start - 1 + len])
-    elif start < 0:
-        i.push(s[-start - len:-start])
-    else:
-        raise BibTeXError('start=0 passed to substring$')
+    string = i.pop()
+    i.push(bibtex_substring(string, start, length))
 
 @builtin('stack$')
 def stack(i):
@@ -265,16 +255,14 @@ def swap(i):
 
 @builtin('text.length$')
 def text_length(i):
-    # FIXME special characters and braces
     s = i.pop()
     i.push(bibtex_len(s))
 
 @builtin('text.prefix$')
 def text_prefix(i):
-    # FIXME special characters and braces
     l = i.pop()
     s = i.pop()
-    i.push(s[:l])
+    i.push(bibtex_prefix(s, l))
 
 @builtin('top$')
 def top(i):
@@ -309,6 +297,5 @@ def width(i):
 
 @builtin('write$')
 def write(i):
-    #FIXME encodings
     s = i.pop()
     i.output(s)
